HostAeadKeyOptions

Trait HostAeadKeyOptions 

pub trait HostAeadKeyOptions {
    // Required methods
    fn new(&mut self) -> Result<Resource<AeadKeyOptions>>;
    fn can_seal(
        &mut self,
        self_: Resource<AeadKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
    fn can_open(
        &mut self,
        self_: Resource<AeadKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
    fn can_wrap(
        &mut self,
        self_: Resource<AeadKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
    fn can_unwrap(
        &mut self,
        self_: Resource<AeadKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
    fn extractable(
        &mut self,
        self_: Resource<AeadKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
}

Required Methods

fn new(&mut self) -> Result<Resource<AeadKeyOptions>>

fn can_seal( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may seal. Disabled by default.

fn can_open( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may open. Disabled by default.

fn can_wrap( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may wrap key material. Disabled by default.

fn can_unwrap( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may unwrap key material (see can-wrap). Disabled by default.

fn extractable( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key’s material may be exported. Disabled by default.

Implementations on Foreign Types

Source

impl<_T: HostAeadKeyOptions + ?Sized + Send> HostAeadKeyOptions for &mut _T

Source

fn can_seal( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may seal. Disabled by default.

Source

fn can_open( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may open. Disabled by default.

Source

fn can_wrap( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may wrap key material. Disabled by default.

Source

fn can_unwrap( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may unwrap key material (see can-wrap). Disabled by default.

Source

fn extractable( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key’s material may be exported. Disabled by default.

Source

fn new(&mut self) -> Result<Resource<AeadKeyOptions>>

Implementors