HostCipherKeyOptions

Trait HostCipherKeyOptions 

pub trait HostCipherKeyOptions {
    // Required methods
    fn new(&mut self) -> Result<Resource<CipherKeyOptions>>;
    fn can_encrypt(
        &mut self,
        self_: Resource<CipherKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
    fn can_decrypt(
        &mut self,
        self_: Resource<CipherKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
    fn can_wrap(
        &mut self,
        self_: Resource<CipherKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
    fn can_unwrap(
        &mut self,
        self_: Resource<CipherKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
    fn extractable(
        &mut self,
        self_: Resource<CipherKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
}

Required Methods

fn new(&mut self) -> Result<Resource<CipherKeyOptions>>

fn can_encrypt( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may encrypt. Disabled by default.

fn can_decrypt( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may decrypt. Disabled by default.

fn can_wrap( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may wrap key material. Disabled by default.

fn can_unwrap( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may unwrap key material (see can-wrap). Disabled by default.

fn extractable( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key’s material may be exported. Disabled by default.

Implementations on Foreign Types

Source

impl<_T: HostCipherKeyOptions + ?Sized + Send> HostCipherKeyOptions for &mut _T

Source

fn can_encrypt( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may encrypt. Disabled by default.

Source

fn can_decrypt( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may decrypt. Disabled by default.

Source

fn can_wrap( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may wrap key material. Disabled by default.

Source

fn can_unwrap( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may unwrap key material (see can-wrap). Disabled by default.

Source

fn extractable( &mut self, self_: Resource<CipherKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key’s material may be exported. Disabled by default.

Source

fn new(&mut self) -> Result<Resource<CipherKeyOptions>>

Implementors