HostDigest

Trait HostDigest 

pub trait HostDigest: Send {
    // Required method
    fn algorithm_name(&mut self, self_: Resource<Digest>) -> Result<String>;
}

Required Methods

fn algorithm_name(&mut self, self_: Resource<Digest>) -> Result<String>

The registry name of the algorithm this resource is bound to, e.g. "SHA-256" (as crypto.subtle.digest spells it). For a digest the algorithm is the hash, so there is no separate algorithm-hash getter.

Implementations on Foreign Types

Source

impl<_T: HostDigest + ?Sized + Send> HostDigest for &mut _T

Source

fn algorithm_name(&mut self, self_: Resource<Digest>) -> Result<String>

The registry name of the algorithm this resource is bound to, e.g. "SHA-256" (as crypto.subtle.digest spells it). For a digest the algorithm is the hash, so there is no separate algorithm-hash getter.

Implementors