pub trait HostIkm {
// Required methods
fn can_derive_bits(&mut self, self_: Resource<Ikm>) -> Result<bool>;
fn can_derive_key(&mut self, self_: Resource<Ikm>) -> Result<bool>;
}Required Methods
Sourcefn can_derive_bits(&mut self, self_: Resource<Ikm>) -> Result<bool>
fn can_derive_bits(&mut self, self_: Resource<Ikm>) -> Result<bool>
Whether inputs prepared from this material may yield raw bits.
Sourcefn can_derive_key(&mut self, self_: Resource<Ikm>) -> Result<bool>
fn can_derive_key(&mut self, self_: Resource<Ikm>) -> Result<bool>
Whether inputs prepared from this material may mint keys.
Implementations on Foreign Types
Sourceimpl<_T: HostIkm + ?Sized + Send> HostIkm for &mut _T
impl<_T: HostIkm + ?Sized + Send> HostIkm for &mut _T
Sourcefn can_derive_bits(&mut self, self_: Resource<Ikm>) -> Result<bool>
fn can_derive_bits(&mut self, self_: Resource<Ikm>) -> Result<bool>
Whether inputs prepared from this material may yield raw bits.
Sourcefn can_derive_key(&mut self, self_: Resource<Ikm>) -> Result<bool>
fn can_derive_key(&mut self, self_: Resource<Ikm>) -> Result<bool>
Whether inputs prepared from this material may mint keys.