pub trait HostSecretKey: Send {
// Required methods
fn algorithm_name(&mut self, self_: Resource<SecretKey>) -> Result<String>;
fn can_derive_bits(&mut self, self_: Resource<SecretKey>) -> Result<bool>;
fn can_derive_key(&mut self, self_: Resource<SecretKey>) -> Result<bool>;
fn extractable(&mut self, self_: Resource<SecretKey>) -> Result<bool>;
}Required Methods
Sourcefn algorithm_name(&mut self, self_: Resource<SecretKey>) -> Result<String>
fn algorithm_name(&mut self, self_: Resource<SecretKey>) -> Result<String>
See public-key.algorithm-name.
Sourcefn can_derive_bits(&mut self, self_: Resource<SecretKey>) -> Result<bool>
fn can_derive_bits(&mut self, self_: Resource<SecretKey>) -> Result<bool>
Whether inputs agreed by this key may yield raw bits. See
agreement-key-options.can-derive-bits.
Sourcefn can_derive_key(&mut self, self_: Resource<SecretKey>) -> Result<bool>
fn can_derive_key(&mut self, self_: Resource<SecretKey>) -> Result<bool>
Whether inputs agreed by this key may mint keys. See
agreement-key-options.can-derive-key.
Sourcefn extractable(&mut self, self_: Resource<SecretKey>) -> Result<bool>
fn extractable(&mut self, self_: Resource<SecretKey>) -> Result<bool>
Whether the export functions may return this key’s material.
See agreement-key-options.extractable.
Implementations on Foreign Types
Sourceimpl<_T: HostSecretKey + ?Sized + Send> HostSecretKey for &mut _T
impl<_T: HostSecretKey + ?Sized + Send> HostSecretKey for &mut _T
Sourcefn algorithm_name(&mut self, self_: Resource<SecretKey>) -> Result<String>
fn algorithm_name(&mut self, self_: Resource<SecretKey>) -> Result<String>
See public-key.algorithm-name.
Sourcefn can_derive_bits(&mut self, self_: Resource<SecretKey>) -> Result<bool>
fn can_derive_bits(&mut self, self_: Resource<SecretKey>) -> Result<bool>
Whether inputs agreed by this key may yield raw bits. See
agreement-key-options.can-derive-bits.
Sourcefn can_derive_key(&mut self, self_: Resource<SecretKey>) -> Result<bool>
fn can_derive_key(&mut self, self_: Resource<SecretKey>) -> Result<bool>
Whether inputs agreed by this key may mint keys. See
agreement-key-options.can-derive-key.
Sourcefn extractable(&mut self, self_: Resource<SecretKey>) -> Result<bool>
fn extractable(&mut self, self_: Resource<SecretKey>) -> Result<bool>
Whether the export functions may return this key’s material.
See agreement-key-options.extractable.