HostPassword

Trait HostPassword 

pub trait HostPassword {
    // Required methods
    fn can_derive_bits(&mut self, self_: Resource<Password>) -> Result<bool>;
    fn can_derive_key(&mut self, self_: Resource<Password>) -> Result<bool>;
}

Required Methods

fn can_derive_bits(&mut self, self_: Resource<Password>) -> Result<bool>

Whether inputs prepared from this password may yield raw bits.

fn can_derive_key(&mut self, self_: Resource<Password>) -> Result<bool>

Whether inputs prepared from this password may mint keys.

Implementations on Foreign Types

Source

impl<_T: HostPassword + ?Sized + Send> HostPassword for &mut _T

Source

fn can_derive_bits(&mut self, self_: Resource<Password>) -> Result<bool>

Whether inputs prepared from this password may yield raw bits.

Source

fn can_derive_key(&mut self, self_: Resource<Password>) -> Result<bool>

Whether inputs prepared from this password may mint keys.

Implementors