Host

pub trait Host {
    // Required method
    fn make_digest(
        &mut self,
        variant: Sha2Variant,
    ) -> Result<Result<Resource<Digest>, Error>>;
}

Required Methods

fn make_digest( &mut self, variant: Sha2Variant, ) -> Result<Result<Resource<Digest>, Error>>

A digest bound to the declared SHA-2 variant. Fails with error.unsupported if this implementation does not serve the variant.

Implementations on Foreign Types

Source

impl<_T: Host + ?Sized> Host for &mut _T

Source

fn make_digest( &mut self, variant: Sha2Variant, ) -> Result<Result<Resource<Digest>, Error>>

A digest bound to the declared SHA-2 variant. Fails with error.unsupported if this implementation does not serve the variant.

Implementors