HostSigningKeyOptions

Trait HostSigningKeyOptions 

pub trait HostSigningKeyOptions {
    // Required methods
    fn new(&mut self) -> Result<Resource<SigningKeyOptions>>;
    fn can_sign(
        &mut self,
        self_: Resource<SigningKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
    fn extractable(
        &mut self,
        self_: Resource<SigningKeyOptions>,
        allowed: bool,
    ) -> Result<()>;
}

Required Methods

fn new(&mut self) -> Result<Resource<SigningKeyOptions>>

fn can_sign( &mut self, self_: Resource<SigningKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may sign. Disabled by default, and it is the sole usage, so it must be enabled for the mint to succeed (an untouched options resource fails error.not-permitted).

fn extractable( &mut self, self_: Resource<SigningKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key’s material may be exported (signing-key.export-key-jwk/-pkcs8 and the to-wrap-input-* functions). Disabled by default.

Implementations on Foreign Types

Source

impl<_T: HostSigningKeyOptions + ?Sized + Send> HostSigningKeyOptions for &mut _T

Source

fn can_sign( &mut self, self_: Resource<SigningKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key may sign. Disabled by default, and it is the sole usage, so it must be enabled for the mint to succeed (an untouched options resource fails error.not-permitted).

Source

fn extractable( &mut self, self_: Resource<SigningKeyOptions>, allowed: bool, ) -> Result<()>

Whether the minted key’s material may be exported (signing-key.export-key-jwk/-pkcs8 and the to-wrap-input-* functions). Disabled by default.

Source

fn new(&mut self) -> Result<Resource<SigningKeyOptions>>

Implementors