pub trait HostAeadKeyOptions {
// Required methods
fn new(&mut self) -> Result<Resource<AeadKeyOptions>>;
fn can_seal(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>;
fn can_open(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>;
fn can_wrap(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>;
fn can_unwrap(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>;
fn extractable(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>;
}Required Methods
fn new(&mut self) -> Result<Resource<AeadKeyOptions>>
Sourcefn can_seal(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn can_seal( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key may seal. Disabled by default.
Sourcefn can_open(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn can_open( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key may open. Disabled by default.
Sourcefn can_wrap(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn can_wrap( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key may wrap key material. Disabled by
default.
Sourcefn can_unwrap(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn can_unwrap( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key may unwrap key material (see
can-wrap). Disabled by default.
Sourcefn extractable(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn extractable( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key’s material may be exported. Disabled by default.
Implementations on Foreign Types
Sourceimpl<_T: HostAeadKeyOptions + ?Sized + Send> HostAeadKeyOptions for &mut _T
impl<_T: HostAeadKeyOptions + ?Sized + Send> HostAeadKeyOptions for &mut _T
Sourcefn can_seal(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn can_seal( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key may seal. Disabled by default.
Sourcefn can_open(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn can_open( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key may open. Disabled by default.
Sourcefn can_wrap(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn can_wrap( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key may wrap key material. Disabled by
default.
Sourcefn can_unwrap(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn can_unwrap( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key may unwrap key material (see
can-wrap). Disabled by default.
Sourcefn extractable(
&mut self,
self_: Resource<AeadKeyOptions>,
allowed: bool,
) -> Result<()>
fn extractable( &mut self, self_: Resource<AeadKeyOptions>, allowed: bool, ) -> Result<()>
Whether the minted key’s material may be exported. Disabled by default.