pub trait HostDeriveOptions {
// Required methods
fn new(&mut self) -> Result<Resource<DeriveOptions>>;
fn can_derive_bits(
&mut self,
self_: Resource<DeriveOptions>,
allowed: bool,
) -> Result<()>;
fn can_derive_key(
&mut self,
self_: Resource<DeriveOptions>,
allowed: bool,
) -> Result<()>;
}Required Methods
fn new(&mut self) -> Result<Resource<DeriveOptions>>
Sourcefn can_derive_bits(
&mut self,
self_: Resource<DeriveOptions>,
allowed: bool,
) -> Result<()>
fn can_derive_bits( &mut self, self_: Resource<DeriveOptions>, allowed: bool, ) -> Result<()>
Whether inputs built on this base secret may yield raw bits
through derive-input.derive-bits, and — because an extractable
key is bits disclosure by other means — whether they may mint
extractable keys. Disabled by default.
Sourcefn can_derive_key(
&mut self,
self_: Resource<DeriveOptions>,
allowed: bool,
) -> Result<()>
fn can_derive_key( &mut self, self_: Resource<DeriveOptions>, allowed: bool, ) -> Result<()>
Whether inputs built on this base secret may mint keys through
the target interfaces’ derive-key. Disabled by default.
Implementations on Foreign Types
Sourceimpl<_T: HostDeriveOptions + ?Sized + Send> HostDeriveOptions for &mut _T
impl<_T: HostDeriveOptions + ?Sized + Send> HostDeriveOptions for &mut _T
Sourcefn can_derive_bits(
&mut self,
self_: Resource<DeriveOptions>,
allowed: bool,
) -> Result<()>
fn can_derive_bits( &mut self, self_: Resource<DeriveOptions>, allowed: bool, ) -> Result<()>
Whether inputs built on this base secret may yield raw bits
through derive-input.derive-bits, and — because an extractable
key is bits disclosure by other means — whether they may mint
extractable keys. Disabled by default.
Sourcefn can_derive_key(
&mut self,
self_: Resource<DeriveOptions>,
allowed: bool,
) -> Result<()>
fn can_derive_key( &mut self, self_: Resource<DeriveOptions>, allowed: bool, ) -> Result<()>
Whether inputs built on this base secret may mint keys through
the target interfaces’ derive-key. Disabled by default.