pub trait HostPublicKey: Send {
// Required method
fn algorithm_name(&mut self, self_: Resource<PublicKey>) -> Result<String>;
}Required Methods
Sourcefn algorithm_name(&mut self, self_: Resource<PublicKey>) -> Result<String>
fn algorithm_name(&mut self, self_: Resource<PublicKey>) -> Result<String>
The registry name of the algorithm family this key is bound to,
e.g. "X25519" (the Web Cryptography API’s
KeyAlgorithm.name).
Implementations on Foreign Types
Sourceimpl<_T: HostPublicKey + ?Sized + Send> HostPublicKey for &mut _T
impl<_T: HostPublicKey + ?Sized + Send> HostPublicKey for &mut _T
Sourcefn algorithm_name(&mut self, self_: Resource<PublicKey>) -> Result<String>
fn algorithm_name(&mut self, self_: Resource<PublicKey>) -> Result<String>
The registry name of the algorithm family this key is bound to,
e.g. "X25519" (the Web Cryptography API’s
KeyAlgorithm.name).