pub trait HostPassword {
// Required methods
fn can_derive_bits(&mut self, self_: Resource<Password>) -> Result<bool>;
fn can_derive_key(&mut self, self_: Resource<Password>) -> Result<bool>;
}Required Methods
Sourcefn can_derive_bits(&mut self, self_: Resource<Password>) -> Result<bool>
fn can_derive_bits(&mut self, self_: Resource<Password>) -> Result<bool>
Whether inputs prepared from this password may yield raw bits.
Sourcefn can_derive_key(&mut self, self_: Resource<Password>) -> Result<bool>
fn can_derive_key(&mut self, self_: Resource<Password>) -> Result<bool>
Whether inputs prepared from this password may mint keys.
Implementations on Foreign Types
Sourceimpl<_T: HostPassword + ?Sized + Send> HostPassword for &mut _T
impl<_T: HostPassword + ?Sized + Send> HostPassword for &mut _T
Sourcefn can_derive_bits(&mut self, self_: Resource<Password>) -> Result<bool>
fn can_derive_bits(&mut self, self_: Resource<Password>) -> Result<bool>
Whether inputs prepared from this password may yield raw bits.
Sourcefn can_derive_key(&mut self, self_: Resource<Password>) -> Result<bool>
fn can_derive_key(&mut self, self_: Resource<Password>) -> Result<bool>
Whether inputs prepared from this password may mint keys.